#region Information
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------------------------------------------------
// Project       : Net Vigilant Network Monitor
// FileName      : ClsSiffer.cs
// Created       : 24th Nov 2007
// Modified On   : 24th Nov 2007
//--------------------------------------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#endregion

#region References
using System;
using System.Collections.Generic;
using System.Data ; 
using System.Text;
using System.Runtime.InteropServices;
using System.Net;
using System.Net.NetworkInformation;
using System.Diagnostics;
using Tamir.IPLib;
using Tamir.IPLib.Packets;
  
#endregion

#region ClsSniffer Class Definition
namespace prjNetVigilant
{
    /// <summary>
    /// 
    /// </summary>
    public class ClsSniffer
    {
        #region Variables
        /// <summary>
        /// 
        /// </summary>
        private NetworkInterface[] AdapterList;
        /// <summary>
        /// 
        /// </summary>
        private PcapDevice Device;
        /// <summary>
        /// Dataset for storing packet information
        /// </summary>
        public DataSet dsCapturedPackets;
        /// <summary>
        /// Event raised when a packet is captured.
        /// </summary>
        /// <returns></returns>
        public delegate DataSet OnPacketArrival();
        Int32[] data;
        
        #endregion

        #region Constructor
        /// <summary>
        /// 
        /// </summary>
        public ClsSniffer()
        {
            dsCapturedPackets = new DataSet();
            DataTable table = new DataTable("tblPackets");
            dsCapturedPackets.Tables.Add(table);
 
            DataColumn colNo = new DataColumn ("Packet Length");
            colNo.DataType = System.Type.GetType("System.Object");

            DataColumn colTime = new DataColumn("Time");
            colTime.DataType = System.Type.GetType("System.DateTime");

            DataColumn colSource = new DataColumn("Source IP");
            colSource.DataType = System.Type.GetType("System.Object");

            DataColumn colDestination = new DataColumn("Destination IP");
            colDestination.DataType = System.Type.GetType("System.Object");

            DataColumn colSport = new DataColumn("Source Port");
            colSport.DataType = System.Type.GetType("System.Object");

            DataColumn colDport = new DataColumn("Destination Port");
            colDport.DataType = System.Type.GetType("System.Object");

            DataColumn colProtocol = new DataColumn("Protocol");
            colProtocol.DataType = System.Type.GetType("System.Object");

            DataColumn colPacketHeader = new DataColumn("Packet Header");
            colPacketHeader.DataType = System.Type.GetType("System.Object");

            DataColumn colPacketData = new DataColumn("Packet Data");
            colPacketData.DataType = System.Type.GetType("System.Object");

            dsCapturedPackets.Tables[0].Columns.Add(colNo);
            dsCapturedPackets.Tables[0].Columns.Add(colTime );
            dsCapturedPackets.Tables[0].Columns.Add(colSource );
            dsCapturedPackets.Tables[0].Columns.Add(colDestination );
            dsCapturedPackets.Tables[0].Columns.Add(colSport);
            dsCapturedPackets.Tables[0].Columns.Add(colDport);
            dsCapturedPackets.Tables[0].Columns.Add(colProtocol);
            dsCapturedPackets.Tables[0].Columns.Add(colPacketHeader);
            dsCapturedPackets.Tables[0].Columns.Add(colPacketData);
           
        }

        
        #endregion

        #region Member Functions
        /// <summary>
        /// Gets the list fo all available network interfaces
        /// </summary>
        /// <returns></returns>
        public NetworkInterface[] ListNetworkInterfaces()
        {
            try
            {
                Debug.WriteLine("In : ListNetworkInterfaces()"); 
                AdapterList = NetworkInterface.GetAllNetworkInterfaces();
                return (AdapterList);
            }
            catch (Exception e)
            {
                Debug.WriteLine("Failed In : ListNetworkInterfaces() ::  " + e.Message);
                return (null);
            }
        }
       /// <summary>
       /// Starts packet capture using the selected network interface.
       /// </summary>
       /// <param name="NetInterface">Selected Network Interface</param>
        public void  StartPacketCapture(NetworkInterface NetInterface)
        {  
            
            PcapDeviceList devices = SharpPcap.GetAllDevices();
            for (int i =0;i < devices.Count ;i++ )
            {   //		PcapName	starts with "\\Device\\NPF_

                if ("\\Device\\NPF_" + NetInterface.Id.ToString() == devices[i].PcapName.ToString())
                {
                    Device = devices[i]; break;
                }
            }

            
            Trace.Write(Device.PcapName);

            Device.PcapOnPacketArrival += new SharpPcap.PacketArrivalEvent(Device_PcapOnPacketArrival);
               
            Device.PcapOpen(true, 1000);
            Device.PcapStartCapture();
            
          
        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="packet"></param>
        private void Device_PcapOnPacketArrival(object sender, Packet packet)
        {
            data = new Int32 [packet.PcapHeader.PacketLength]; 
            DateTime time = packet.PcapHeader.Date;
            int len = packet.PcapHeader.PacketLength ;
              
             DataRow row;
                row = dsCapturedPackets.Tables[0].NewRow();
                row[0] = len.ToString();
                row[1] = System.DateTime.Now;

                string  strData =null ;
                for (int i = 0; i < packet.Data .Length - 1; i++)
                {
                    strData +=packet.Data[i];

                }
                string  strHeader = null ;
                for (int i = 0; i < packet.Header.Length - 1; i++)
                {
                   strHeader += packet.Header[i];
                }
                row[7] = strHeader  ;
                row[8] = strData ;   

            if (packet is TCPPacket)
            {

                TCPPacket tcp = (TCPPacket)packet;
                //string srcIp = tcp.SourceAddress;
                //string dstIp = tcp.DestinationAddress;
                //int srcPort = tcp.SourcePort;
                //int dstPort = tcp.DestinationPort;
               
                row[2] = tcp.SourceAddress;
                row[3] = tcp.DestinationAddress;
                row[4] = tcp.SourcePort;
                row[5] = tcp.DestinationPort;
                row[6] = "TCP";
                  
            }

            else if (packet is ARPPacket)
            {
                ARPPacket arp = (ARPPacket)packet;
                  row[2] = arp.SourceProtoAddress  ;
                  row[3] = arp.DestinationProtoAddress ;
                  row[4] = arp.SourceHwAddress ;
                  row[5] = arp.DestinationHwAddress ;
                  row[6] = "ARP";
                    
            }

            else if (packet is ICMPPacket)
            {
                ICMPPacket icmp = (ICMPPacket)packet;

                  row[2] = icmp .SourceAddress ;
                  row[3] = icmp .DestinationAddress; 
                  row[4] = icmp.SourceHwAddress ;
                  row[5] = icmp .DestinationHwAddress;
                  row[6] = "ICMP";
            }

            else if (packet is UDPPacket )
            {
                UDPPacket udp = (UDPPacket )packet ;
                  row[2] =  udp.SourceAddress;  
                  row[3] =  udp.DestinationAddress; 
                  row[4] =  udp.SourcePort; 
                  row[5] =  udp.DestinationPort;
                  row[6] = "UDP";  
            }

            else if (packet is IGMPPacket)
            {
                IGMPPacket igmp = (IGMPPacket)packet;
                row[2] = igmp.SourceAddress; 
                row[3] = igmp.DestinationAddress; 
                row[4] = igmp.SourceHwAddress; 
                row[5] = igmp.DestinationHwAddress;
                row[6] = "IGMP";   

            }

            else if (packet is IPPacket)
            {
                IPPacket ip = (IPPacket)packet;
                row[2] = ip.SourceAddress;
                row[3] = ip.DestinationAddress;
                row[4] = ip.SourceHwAddress;
                row[5] = ip.DestinationHwAddress;
                row[6] = "IP";
            }

            else if (packet is EthernetPacket)
            {
                EthernetPacket e = (EthernetPacket)packet;
                row[2] = "NA";
                row[3] = "NA";
                row[4] = e.SourceHwAddress;
                row[5] = e.DestinationHwAddress;
                row[6] = "Ethernet";
            }

            else 
            {
                row[2] = "NA";
                row[3] = "NA";
                row[4] = "NA";
                row[5] = "NA";
                row[6] = "UnIdentified";
            }
            lock (dsCPLock)
            {
                dsCapturedPackets.Tables[0].Rows.Add(row);
            }
        }
        object dsCPLock = new object();
        /// <summary>
        /// 
        /// </summary>
        public DataSet GetdataSet
        {
           
            get {
                    return this.dsCapturedPackets;
                }
           
            
        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="version"></param>
        /// <returns></returns>
        public TcpStatistics GetTCPStatistics(NetworkInterfaceComponent version)
        {
            {
                IPGlobalProperties properties = IPGlobalProperties.GetIPGlobalProperties();
                TcpStatistics tcpstat = null;
                switch (version)
                {
                    case NetworkInterfaceComponent.IPv4:
                        tcpstat = properties.GetTcpIPv4Statistics();
                        return tcpstat; 
                       
                    case NetworkInterfaceComponent.IPv6:
                        tcpstat = properties.GetTcpIPv6Statistics();
                        return tcpstat; 
                    default:
                        return null; 
                }
                
            }

        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="version"></param>
        /// <returns></returns>
        public UdpStatistics GetUDPStatistics(NetworkInterfaceComponent version)
        {
            {
                IPGlobalProperties properties = IPGlobalProperties.GetIPGlobalProperties();
                UdpStatistics Udpstat = null;
                switch (version)
                {
                    case NetworkInterfaceComponent.IPv4:
                        Udpstat = properties.GetUdpIPv4Statistics ();
                        return Udpstat;

                    case NetworkInterfaceComponent.IPv6:
                        Udpstat = properties.GetUdpIPv6Statistics();
                        return Udpstat;
                    default:
                        return null;
                }
            }
        }
        /// <summary>
        /// 
        /// </summary>
        public void stopPacketCapture()
        {
            if (Device != null)
            {
                if (Device.PcapStarted)
                {
                    Device.PcapStopCapture();
                }
                if (Device.PcapOpened)
                {
                    Device.PcapClose();
                }
            }
        }

#endregion
    }
}

#endregion