#region Information
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------------------------------------------------
// Project       : Net Vigilant Network Monitor
// FileName      : frnNetVigilant.cs
// Created       : 24th Nov 2007
// Modified On   : 24th Nov 2007
//--------------------------------------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#endregion

#region Net Vigilant Network Monitor

#region References

using System;
using System.Collections.Generic;
using System.Collections; 
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Drawing2D;
using System.Net;
using System.Net.NetworkInformation;
using System.Diagnostics;
using Tamir.IPLib.Packets; 
 #endregion
  
namespace prjNetVigilant
{   
    /// <summary>
    /// 
    /// </summary>
    public partial class frmNetVigilant : Form
    {
        #region Private Variables
        private NetworkInterface[] AdapterList;
        private ClsSniffer Sniffer;
        private NetworkInterface CurrentAdapter;
        private object DgvLock;
        private Timer t;
        //public DataSet dsCapturedPackets;
        private DataSet ds;

        #endregion

        #region Constructor
        /// <summary>
        /// Constructor frmNetVigilant
        /// </summary>
        public frmNetVigilant()
        {
            try
            {
                Trace.WriteLine("In : frmNetVigilant Constructor ");

                InitializeComponent();
                Sniffer = new ClsSniffer();
                DgvLock = new object();
                ds = new DataSet();
                this.Resize += new EventHandler(frmNetVigilant_Resize);
                this.DisplayNetworkInterfaces();
                if (dgvAdaptors.RowCount > 0)
                {
                    this.CurrentAdapter = AdapterList[dgvAdaptors.CurrentRow.Index];
                }
                t = new Timer();
                t.Interval = 10000;
                t.Tick += new EventHandler(t_Tick);
                lock (DgvLock)
                {
                    //dgvSniffer.DataSource = Sniffer.dsCapturedPackets;
                    //dgvSniffer.DataMember = Sniffer.dsCapturedPackets.Tables[0].ToString();
                    //dgvSniffer.Refresh();
                    ds.Merge(Sniffer.dsCapturedPackets);
                    dgvSniffer.DataSource = ds; 
                    dgvSniffer.DataMember = ds.Tables[0].ToString();
                    dgvSniffer.Refresh();
                }
            }
            catch(Exception err)
            {
                Trace.WriteLine("Failed In : frmNetVigilant Constructor :: " + err.Message);

            }
        }

               
        #endregion

        #region Functions
        /// <summary>
        /// Displays a List of all Network Interfaces available
        /// </summary>
        void DisplayNetworkInterfaces()
        {
            try
            {
                Trace.WriteLine("In : DisplayNetworkInterfaces");
                AdapterList = Sniffer.ListNetworkInterfaces();
                foreach (NetworkInterface n in AdapterList)
                {
                    DataRow row;
                    if (n.NetworkInterfaceType.CompareTo(NetworkInterfaceType.Ethernet) == 0 || n.NetworkInterfaceType.CompareTo(NetworkInterfaceType.Wireless80211) == 0)
                    {
                        row = dataSet1.Tables[0].NewRow();
                        row[0] = n.Id;
                        row[1] = n.Name;
                        row[2] = n.NetworkInterfaceType;
                        row[3] = n.Description;
                        row[4] = n.OperationalStatus;
                        row[5] = n.Speed;
                        row[6] = n.SupportsMulticast;
                        dataSet1.Tables[0].Rows.Add(row);
                    }
                }
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : DisplayNetworkInterfaces :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        void StartSniffing(NetworkInterface NetInterface)
        {
            try
            {
                Trace.WriteLine("In : StartSniffing");
                if(dgvAdaptors.RowCount ==0)
                {
                    MessageBox.Show("No Network Interfaces / Adapters available for packet capture");
                    return;
                }
                if (NetInterface == null)
                {
                    MessageBox.Show("Please Select an Network Adapter first !");
                    return ;
                }
                    t.Start();
                    dgvAdaptors.Enabled = false;
                        //Clear earlier rows
                        if (dgvSniffer.RowCount > 0)
                        {
                            ds.Tables[0].Rows.Clear();
                            Sniffer.dsCapturedPackets.Tables[0].Rows.Clear();
                            dgvSniffer.Refresh();
                             
                        }

                        //Start Packet capture. 
                        CurrentAdapter = NetInterface;
                        Sniffer.StartPacketCapture(NetInterface);
                 }
                catch (Exception err)
                {

                    Trace.WriteLine("Failed In : StartSniffing :: " + err.Message);
                }
        }
        /// <summary>
        /// 
        /// </summary>
        private void StopSniffing()
        {
            try
            {
                Trace.WriteLine("In : StopSniffing ");

                Sniffer.stopPacketCapture();
                dgvAdaptors.Enabled = true;
                t.Stop();
                ClearTreeview();
                this.CurrentAdapter = null;
                //null current adapter
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : StopSniffing :: " + err.Message);

            }
        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="ds"></param>
        /// <param name="Title"></param>
        /// <param name="Data"></param>
        private void AddRow(ref DataSet ds, String Title, String Data)
        {
            try
            {
                Trace.WriteLine("In : AddRow ");
                DataRow row;
                row = ds.Tables[0].NewRow();
                row[0] = Title;
                row[1] = Data;
                ds.Tables[0].Rows.Add(row);

            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : AddRow :: " + err.Message);
            }
        }
        /// <summary>
        /// Clears the tree view pane
        /// </summary>
        private void ClearTreeview()
        {
            try
            {
                Trace.WriteLine("In : SetTreeView");

                trvPacketDisplay.Nodes[0].Nodes[0].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[1].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[2].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[3].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[4].Nodes[0].Text = "";
                
                trvPacketDisplay.Nodes[0].Nodes[5].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[6].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[7].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[8].Nodes[0].Text = "";

                trvPacketDisplay.Nodes[0].Nodes[9].Nodes[0].Text = "";
                trvPacketDisplay.Nodes[0].Nodes[10].Nodes[0].Text = "";
                trvPacketDisplay.CollapseAll ();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : SetTreeView :: " + err.Message);

            }
        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="index"></param>
        private void SetTreeView(int index)
        {
            try
            {
                
                Trace.WriteLine("In : SetTreeView");

                if(dgvSniffer[6,index].Value.ToString().CompareTo("ARP")==0)
                {
                    trvPacketDisplay.Nodes[0].Nodes[5].Nodes[0].Text = (dgvSniffer[4, index].Value.ToString());
                    trvPacketDisplay.Nodes[0].Nodes[6].Nodes[0].Text = (dgvSniffer[5, index].Value.ToString());
                    trvPacketDisplay.Nodes[0].Nodes[7].Nodes[0].Text = " ";
                    trvPacketDisplay.Nodes[0].Nodes[8].Nodes[0].Text = " ";
                }
                else
                {
                    trvPacketDisplay.Nodes[0].Nodes[5].Nodes[0].Text = " ";
                    trvPacketDisplay.Nodes[0].Nodes[6].Nodes[0].Text = " ";
                    trvPacketDisplay.Nodes[0].Nodes[7].Nodes[0].Text = (dgvSniffer[4, index].Value.ToString());
                    trvPacketDisplay.Nodes[0].Nodes[8].Nodes[0].Text = (dgvSniffer[5, index].Value.ToString());
                }
                trvPacketDisplay.Nodes[0].Nodes[0].Nodes[0].Text = (dgvSniffer[6,index].Value .ToString()+ " Packet");
                trvPacketDisplay.Nodes[0].Nodes[1].Nodes[0].Text = (dgvSniffer[0, index].Value.ToString());
                trvPacketDisplay.Nodes[0].Nodes[2].Nodes[0].Text = (dgvSniffer[1, index].Value.ToString());
                trvPacketDisplay.Nodes[0].Nodes[3].Nodes[0].Text = (dgvSniffer[2, index].Value.ToString());
                trvPacketDisplay.Nodes[0].Nodes[4].Nodes[0].Text = (dgvSniffer[3, index].Value.ToString());              
                trvPacketDisplay.Nodes[0].Nodes[9].Nodes[0].Text = (dgvSniffer[7, index].Value.ToString());
                trvPacketDisplay.Nodes[0].Nodes[10].Nodes[0].Text = (dgvSniffer[8, index].Value.ToString());
                trvPacketDisplay.ExpandAll();  
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : SetTreeView :: " + err.Message);

            }
        }

        /// <summary>
        /// 
        /// </summary>
        private void RemoveFilter()
        {
            try
            {
                Trace.WriteLine("In : RemoveFilter ");
                dgvSniffer.DataSource = null;
                dgvSniffer.DataSource = ds ;
                dgvSniffer.DataMember = ds.Tables[0].TableName;
                //dgvSniffer.DataSource = Sniffer.dsCapturedPackets;
                //dgvSniffer.DataMember = Sniffer.dsCapturedPackets.Tables[0].TableName;
                dgvSniffer.Update();
                dgvSniffer.Refresh();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : RemoveFilter :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="protocol"></param>
        private void SetFilter(string protocol)
        {

            try
            {
                Trace.WriteLine("In : SetFilter ");
                //BindingSource BindingSource1 = new BindingSource(Sniffer.dsCapturedPackets, Sniffer.dsCapturedPackets.Tables[0].TableName);
                BindingSource BindingSource1 = new BindingSource(ds, ds.Tables[0].TableName);

                // Filter the items by protocol
                BindingSource1.Filter = "Protocol='" + protocol + "'";

                // Set the data source for dataGridView1 to BindingSource1.
                dgvSniffer.DataSource = BindingSource1;
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : SetFilter :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        private void SaveFile()
        {
            try
            {
                Trace.WriteLine("In : SaveFile ");
                if (Sniffer.dsCapturedPackets.Tables[0].Rows.Count > 0)
                {
                    OpenFileDialog OFD = new OpenFileDialog();
                    OFD.Title = "Select a XML File";
                    OFD.InitialDirectory = (Application.UserAppDataPath);
                    OFD.Filter = "xml Files(*.xml)|*.xml";
                    string Filename = (OFD.ShowDialog() == DialogResult.OK) ? OFD.FileName : null;
                    if (Filename != null)
                    {
                        Sniffer.dsCapturedPackets.WriteXml(Filename);
                        Sniffer.dsCapturedPackets.Tables[0].Rows.Clear();
                        ds.Clear();
                        ds.Merge(Sniffer.dsCapturedPackets);
                        dgvSniffer.Refresh(); 
                        ClearTreeview(); 
                    }
                }
                else
                {
                    MessageBox.Show("No packets captured !");
                }
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : SaveFile :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        private void OpenFile()
        {
            try
            {
                Trace.WriteLine("In : OpenFile ");
                OpenFileDialog OFD = new OpenFileDialog();
                OFD.Title = "Select a text file";
                OFD.InitialDirectory = (Application.UserAppDataPath);
                OFD.Filter = "xml Files(*.xml)|*.xml";
                string Filename = (OFD.ShowDialog() == DialogResult.OK) ? OFD.FileName : null;
                if (Filename != null)
                {
                    Sniffer.dsCapturedPackets.ReadXml(Filename);
                    ds.Clear();
                    ds.Merge(Sniffer.dsCapturedPackets);
                    dgvSniffer.Refresh();
                }
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : OpenFile :: " + err.Message);
            }
        }       

        
        #endregion

        #region Events
        /// <summary>
        /// Exits Application
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// 
        private void btnExit_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : btnExit_Click");
                Sniffer.stopPacketCapture();  
                this.Dispose(); 
                Application.Exit();
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : btnExit_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// 
        private void frmNetVigilant_Load(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : frmNetVigilant_Load");
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : frmNetVigilant_Load :: " + err.Message);
            }

        }
        int count = 0;
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void t_Tick(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : t_Tick ");

                if (Sniffer.dsCapturedPackets.Tables[0].Rows.Count  > (count + 15))
                {
                    ds.Clear();
                    ds.Merge(Sniffer.dsCapturedPackets);
                    dgvSniffer.DataSource = ds;
                    dgvSniffer.DataMember = ds.Tables[0].ToString();
                    dgvSniffer.Refresh();
                    count = dgvSniffer.RowCount;
                }               
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : t_Tick :: " + err.Message);

            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void frmNetVigilant_Resize(object sender, EventArgs e)
        {
            try 
            {
                Trace.WriteLine("In : frmNetVigilant_Resize  ");          
               
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : frmNetVigilant_Resize :: " + err.Message);          
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void dgvAdaptors_CellContentDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            try
            {
                Trace.WriteLine("In : dgvAdaptors_CellContentDoubleClick");
                this.StartSniffing(AdapterList[dgvAdaptors.CurrentRow.Index]);
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : dgvAdaptors_CellContentDoubleClick :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnStart_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : btnStart_Click ");

                this.StartSniffing(AdapterList[dgvAdaptors.CurrentRow.Index]);

            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : btnStart_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void pingToolStripMenuItem_Click(object sender, EventArgs e)
        {

            try
            {
                Trace.WriteLine("In : pingToolStripMenuItem_Click " );          

                frmPing Ping = new frmPing();
                Ping.Show();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : pingToolStripMenuItem_Click :: " + err.Message);          
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnStop_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : btnStop_Click ");
                this.StopSniffing(); 
                
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : btnStop_Click :: " + err.Message);          

            }
        }
     
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnDelete_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : btnDelete_Click ");
                this.StopSniffing();
                if (Sniffer.dsCapturedPackets.Tables[0].Rows.Count > 0)
                {
                    Sniffer.dsCapturedPackets.Tables[0].Rows.Clear();
                }
                ds.Clear();
                ds.Merge(Sniffer.dsCapturedPackets);
                dgvSniffer.Refresh(); 

            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : btnDelete_Click :: " + err.Message);    
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void tCPStatisticsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : tCPStatisticsToolStripMenuItem_Click");
                if (AdapterList.Length > 0)
                {
                    NetworkInterfaceComponent version = new NetworkInterfaceComponent();
                    TcpStatistics TCPstats = null;
                    dataSet2.Tables[0].Rows.Clear();

                    if (CurrentAdapter.Supports(NetworkInterfaceComponent.IPv4))
                    {
                        version = NetworkInterfaceComponent.IPv4;
                        TCPstats = Sniffer.GetTCPStatistics(version);
                        this.AddRow(ref dataSet2, "  TCP IPV4 STATISTICS ", " ");

                    }
                    else
                    {
                        version = NetworkInterfaceComponent.IPv6;
                        TCPstats = Sniffer.GetTCPStatistics(version);
                        this.AddRow(ref dataSet2, "  TCP IPV6 STATISTICS ", " ");


                    }

                    this.AddRow(ref dataSet2, "  Minimum Transmission Timeout  :", TCPstats.MinimumTransmissionTimeout.ToString());
                    this.AddRow(ref dataSet2, "  Maximum Transmission Timeout  :", TCPstats.MaximumTransmissionTimeout.ToString());
                    this.AddRow(ref dataSet2, "  ", " ");
                    this.AddRow(ref dataSet2, "  CONNECTION DATA", " ");

                    this.AddRow(ref dataSet2, "  Current  : ", TCPstats.CurrentConnections.ToString());
                    this.AddRow(ref dataSet2, "  Cumulative:", TCPstats.CumulativeConnections.ToString());
                    this.AddRow(ref dataSet2, "  Initiated:", TCPstats.ConnectionsInitiated.ToString());
                    this.AddRow(ref dataSet2, "  Accepted:", TCPstats.ConnectionsAccepted.ToString());
                    this.AddRow(ref dataSet2, "  Failed Attempts :", TCPstats.FailedConnectionAttempts.ToString());
                    this.AddRow(ref dataSet2, "  Reset:", TCPstats.ResetConnections.ToString());
                    this.AddRow(ref dataSet2, "  ", " ");

                    this.AddRow(ref dataSet2, "  SEGMENT DATA ", " ");

                    this.AddRow(ref dataSet2, "  Sent :", TCPstats.SegmentsSent.ToString());
                    this.AddRow(ref dataSet2, "  Retransmitted :", TCPstats.SegmentsReceived.ToString());
                    frmPing frmTCPstats = new frmPing(dataSet2, true);

                    frmTCPstats.Show();
                }
                else
                    MessageBox.Show("No Network Interface available to show statistics !");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : tCPStatisticsToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// /
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnSave_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : btnSave_Click ");  
                this.SaveFile();
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : btnSave_Click :: " + err.Message);  
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnOpen_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : btnOpen_Click ");
                this.OpenFile();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : btnOpen_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void whoIsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : whoIsToolStripMenuItem_Click " );
                if (AdapterList.Length > 0)
                {

                    NetworkInterfaceComponent version = new NetworkInterfaceComponent();
                    UdpStatistics UDPstats = null;
                    dataSet2.Tables[0].Rows.Clear();

                    if (CurrentAdapter.Supports(NetworkInterfaceComponent.IPv4))
                    {
                        version = NetworkInterfaceComponent.IPv4;
                        UDPstats = Sniffer.GetUDPStatistics(version);
                        this.AddRow(ref dataSet2, "  UDP IPV4 STATISTICS ", " ");

                    }
                    else
                    {
                        version = NetworkInterfaceComponent.IPv6;
                        UDPstats = Sniffer.GetUDPStatistics(version);
                        this.AddRow(ref dataSet2, "  UDP IPV6 STATISTICS ", " ");
                    }

                    this.AddRow(ref dataSet2, "  Datagrams Received  :", UDPstats.DatagramsReceived.ToString());
                    this.AddRow(ref dataSet2, "  Datagrams Sent  :", UDPstats.DatagramsSent.ToString());
                    this.AddRow(ref dataSet2, "  Incoming Datagrams Discarded : ", UDPstats.IncomingDatagramsDiscarded.ToString());
                    this.AddRow(ref dataSet2, "  ncoming Datagrams With Errors :", UDPstats.IncomingDatagramsWithErrors.ToString());
                    this.AddRow(ref dataSet2, "  UDP Listeners   :", UDPstats.UdpListeners.ToString());

                    frmPing frmTCPstats = new frmPing(dataSet2, false);

                    frmTCPstats.Show();

                }
                else
                    MessageBox.Show("No Network Interface available to show statistics !");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : whoIsToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void tCPToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : tCPToolStripMenuItem_Click ");
                this.SetFilter("TCP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : tCPToolStripMenuItem_Click :: " + err.Message);
            }
         }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void removeFilterToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : removeFilterToolStripMenuItem_Click ");
                this.RemoveFilter();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : removeFilterToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void uDPToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : uDPToolStripMenuItem_Click ");
                this.SetFilter("UDP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : uDPToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void iGMPToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : uDPToolStripMenuItem_Click");
                this.SetFilter("IGMP");
            }
            catch (Exception err)
            {
                
                Trace.WriteLine("Failed In : uDPToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// /
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void iCMPToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : iCMPToolStripMenuItem_Click ");
                this.SetFilter("ICMP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : iCMPToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void aRPToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : aRPToolStripMenuItem_Click ");
                this.SetFilter("ARP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : aRPToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void unspecifiedToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : unspecifiedToolStripMenuItem_Click ");
                this.SetFilter("Unspecified");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : unspecifiedToolStripMenuItem_Click :: " + err.Message);
                
            }
        }
        
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void removeFilterToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : removeFilterToolStripMenuItem1_Click ");
                this.RemoveFilter();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : removeFilterToolStripMenuItem1_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// /
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void aRPToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : aRPToolStripMenuItem1_Click ");
                this.SetFilter("ARP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : aRPToolStripMenuItem1_Click :: " + err.Message);
            } 
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void iCMPToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : iCMPToolStripMenuItem1_Click ");
                this.SetFilter("ICMP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : iCMPToolStripMenuItem1_Click :: " + err.Message);
            } 

        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void iGMPToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : iGMPToolStripMenuItem1_Click" );
                this.SetFilter("IGMP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : iGMPToolStripMenuItem1_Click :: " + err.Message);
            }  

        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void tCPToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : tCPToolStripMenuItem1_Click ");
                this.SetFilter("TCP");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : tCPToolStripMenuItem1_Click :: " + err.Message);
            }  

        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void uDPToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : uDPToolStripMenuItem1_Click ");
                this.SetFilter("UDP");

            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : uDPToolStripMenuItem1_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void unspecifiedToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : unspecifiedToolStripMenuItem1_Click ");
                this.SetFilter("Unspecified");
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : unspecifiedToolStripMenuItem1_Click :: " + err.Message);
            } 

        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : exitToolStripMenuItem_Click ");
                Application.Exit();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : exitToolStripMenuItem_Click :: " + err.Message);
            } 
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void openLogFileToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : openLogFileToolStripMenuItem_Click");
                this.OpenFile();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : openLogFileToolStripMenuItem_Click :: " + err.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void savePacketsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine(" In : savePacketsToolStripMenuItem_Click");
                this.SaveFile();
            }
            catch (Exception err) 
            {

                Trace.WriteLine("Failed In : savePacketsToolStripMenuItem_Click :: " + err.Message);
            }
        }
        
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void aboutNetVigilantToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : aboutNetVigilantToolStripMenuItem_Click ");
                Form AboutForm = new Form();
                AboutForm.Text = "Net Vigilant Network Monitor";

                Label lbl = new Label();
                lbl.Size = AboutForm.Size;
                lbl.Location = new Point(0, 0);
                lbl.TextAlign = ContentAlignment.TopCenter;
                lbl.Text = Environment.NewLine + Environment.NewLine + " Net Vigilant Network Monitor V1.0.0.0 ";

                AboutForm.Controls.Add(lbl);

                AboutForm.ShowDialog();
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : aboutNetVigilantToolStripMenuItem_Click :: " + err.Message);
            }
        }
      
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void helpTopicsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            try
            {
                Trace.WriteLine("In : helpTopicsToolStripMenuItem_Click ::");
                Form frmHelp = new Form();
                frmHelp.Text = "Help Topics";

                Label lbl = new Label();
                lbl.Size = frmHelp.Size;
                lbl.Location = new Point(0, 0);
                lbl.TextAlign = ContentAlignment.TopCenter;
                lbl.Text = "Under Construction";
                lbl.Text += "Please refer to the user manual";  
                frmHelp.Controls.Add(lbl);

                frmHelp.ShowDialog();
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : helpTopicsToolStripMenuItem_Click :: " + err.Message);
            }
        }
       
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void aRPToolStripMenuItem2_Click(object sender, EventArgs e)
        {

        }
       
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ProtocoltoolStripMenuItem1_DropDownItemClicked(object sender, ToolStripItemClickedEventArgs e)
        {
            try
            {
                Trace.WriteLine("In : ProtocoltoolStripMenuItem1_DropDownItemClicked ::");
                switch (e.ClickedItem.ToString())
                {
                    case "ARP":
                        {
                            this.SetFilter("ARP");
                            break;
                        }
                    case "UDP":
                        {
                            MessageBox.Show("UDP");
                            this.SetFilter("UDP");
                            break;
                        }
                    case "TCP":
                        {
                            this.SetFilter("TCP");
                            break;
                        }
                    case "ICMP":
                        {
                            this.SetFilter("ICMP");
                            break;
                        }
                    case "IGMP":
                        {
                            this.SetFilter("IGMP");
                            break;
                        }
                    case "Unspecified":
                        {
                            this.SetFilter("Unspecified");
                            break;
                        }
                }
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : ProtocoltoolStripMenuItem1_DropDownItemClicked :: " + err.Message  );
            }
        }
        
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SourceAddressFiltertoolStripMenuItem1_Click(object sender, EventArgs e)
        {
            
        }
        
      
        
       /// <summary>
       /// 
       /// </summary>
       /// <param name="sender"></param>
       /// <param name="e"></param>
      
        private void dgvSniffer_CellDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            try
            {
                Trace.WriteLine("In : dgvSniffer_CellContentClick ");
                if (dgvSniffer.CurrentRow != null)
                {
                    if(e.RowIndex != -1)
                        this.SetTreeView(e.RowIndex);
                }
            }
            catch (Exception err)
            {

                Trace.WriteLine("Failed In : dgvSniffer_CellContentClick :: " + err.Message);
            }
        }

        #endregion 

        private void frmNetVigilant_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                Trace.WriteLine("In : frmNetVigilant_FormClosing ");
                Sniffer.stopPacketCapture();
            }
            catch (Exception err)
            {
                Trace.WriteLine("Failed In : frmNetVigilant_FormClosing :: " + err.Message);
            }
        }

       
    }
}

#endregion
